Module metadata

Module metadata 

Function and type level metadata for Rust to SQL translation

Like all of the sql_entity_graph APIs, this is considered internal to the pgrx framework and very subject to change between versions. While you may use this, please do it with caution.

Macros

impl_sql_translatable
Implements SqlTranslatable for a type with a fixed external SQL mapping.

Structs

FunctionMetadataEntity
FunctionMetadataTypeEntity
FunctionMetadataTypeResolutionEntity

Enums

ArgumentError
Returns
Describes the RETURNS of CREATE FUNCTION … RETURNS … See the PostgreSQL documentation for [CREATE FUNCTION] [CREATE FUNCTION]: https://www.postgresql.org/docs/current/sql-createfunction.html
ReturnsError
ReturnsRef
Const-friendly return metadata.
SqlArrayMapping
SqlArrayMappingRef
SqlMapping
Describes ways that Rust types are mapped into SQL
SqlMappingRef
Const-friendly SQL mapping metadata.
TypeOrigin
Describes whether a SQL type reference should resolve to schema emitted by this extension or be treated as an external SQL type.

Traits

FunctionMetadata
Provide SQL generation related information on functions
SqlTranslatable
A value which can be represented in SQL

Functions

array_argument_sql
array_return_sql
setof_return_sql
table_item_sql