pub enum TypeOrigin {
ThisExtension,
External,
}Expand description
Describes whether a SQL type reference should resolve to schema emitted by this extension or be treated as an external SQL type.
Variants
ThisExtension
The extension being built is responsible for emitting this type into the schema graph.
External
The type already exists outside this extension’s schema graph.