ToSqlConfigEntity

Struct ToSqlConfigEntity 

pub struct ToSqlConfigEntity<'a> {
    pub enabled: bool,
    pub content: Option<&'a str>,
}
Represents configuration options for tuning the SQL generator.

When an item that can be rendered to SQL has these options at hand, they should be respected. If an item does not have them, then it is not expected that the SQL generation for those items can be modified.

The default configuration has enabled set to true, which indicates that the default SQL generation behavior will be used.

When enabled is false, no SQL is generated for the item being configured.

Fields

enabled: boolcontent: Option<&'a str>

Implementations

Source

impl ToSqlConfigEntity<'_>

pub fn to_sql( &self, entity: &SqlGraphEntity<'_>, context: &PgrxSql<'_>, ) -> Option<Result<String>>

Given a SqlGraphEntity, this function converts it to SQL based on the current configuration.

If the config overrides the default behavior (i.e. using the ToSql trait), then Some(eyre::Result) is returned. If the config does not override the default behavior, then None is returned. This can be used to dispatch SQL generation in a single line, e.g.:

config.to_sql(entity, context).unwrap_or_else(|| entity.to_sql(context))?