Function and type level metadata for Rust to SQL translation
Like all of the
sql_entity_graphAPIs, this is considered internal to thepgrxframework and very subject to change between versions. While you may use this, please do it with caution.
Macros
- impl_
sql_ translatable - Implements
SqlTranslatablefor a type with a fixed external SQL mapping.
Structs
Enums
- Argument
Error - Returns
- Describes the RETURNS of CREATE FUNCTION … RETURNS … See the PostgreSQL documentation for [CREATE FUNCTION] [CREATE FUNCTION]: https://www.postgresql.org/docs/current/sql-createfunction.html
- Returns
Error - Returns
Ref - Const-friendly return metadata.
- SqlArray
Mapping - SqlArray
Mapping Ref - SqlMapping
- Describes ways that Rust types are mapped into SQL
- SqlMapping
Ref - Const-friendly SQL mapping metadata.
- Type
Origin - Describes whether a SQL type reference should resolve to schema emitted by this extension or be treated as an external SQL type.
Traits
- Function
Metadata - Provide SQL generation related information on functions
- SqlTranslatable
- A value which can be represented in SQL