PgrxSql

Struct PgrxSql 

pub struct PgrxSql<'a> {
Show 17 fields pub control: ControlFile, pub graph: StableGraph<SqlGraphEntity<'a>, SqlGraphRequires>, pub graph_root: NodeIndex, pub graph_bootstrap: Option<NodeIndex>, pub graph_finalize: Option<NodeIndex>, pub schemas: HashMap<SchemaEntity<'a>, NodeIndex>, pub extension_sqls: HashMap<ExtensionSqlEntity<'a>, NodeIndex>, pub externs: HashMap<PgExternEntity<'a>, NodeIndex>, pub types: HashMap<PostgresTypeEntity<'a>, NodeIndex>, pub builtin_types: HashMap<String, NodeIndex>, pub enums: HashMap<PostgresEnumEntity<'a>, NodeIndex>, pub ords: HashMap<PostgresOrdEntity<'a>, NodeIndex>, pub hashes: HashMap<PostgresHashEntity<'a>, NodeIndex>, pub aggregates: HashMap<PgAggregateEntity<'a>, NodeIndex>, pub triggers: HashMap<PgTriggerEntity<'a>, NodeIndex>, pub extension_name: String, pub versioned_so: bool,
}
A generator for SQL.

Consumes a base mapping of types (typically pgrx::DEFAULT_TYPEID_SQL_MAPPING), a ControlFile, and collections of each SQL entity.

During construction, a Directed Acyclic Graph is formed out the dependencies. For example, an item detect_dog(x: &[u8]) -> animals::Dog would have have a relationship with animals::Dog.

Typically, PgrxSql types are constructed in a pgrx::pg_binary_magic!() call in a binary out of entities collected during a pgrx::pg_module_magic!() call in a library.

Fields

control: ControlFilegraph: StableGraph<SqlGraphEntity<'a>, SqlGraphRequires>graph_root: NodeIndexgraph_bootstrap: Option<NodeIndex>graph_finalize: Option<NodeIndex>schemas: HashMap<SchemaEntity<'a>, NodeIndex>extension_sqls: HashMap<ExtensionSqlEntity<'a>, NodeIndex>externs: HashMap<PgExternEntity<'a>, NodeIndex>types: HashMap<PostgresTypeEntity<'a>, NodeIndex>builtin_types: HashMap<String, NodeIndex>enums: HashMap<PostgresEnumEntity<'a>, NodeIndex>ords: HashMap<PostgresOrdEntity<'a>, NodeIndex>hashes: HashMap<PostgresHashEntity<'a>, NodeIndex>aggregates: HashMap<PgAggregateEntity<'a>, NodeIndex>triggers: HashMap<PgTriggerEntity<'a>, NodeIndex>extension_name: Stringversioned_so: bool

Implementations

Source

impl<'a> PgrxSql<'a>

pub fn build( entities: impl Iterator<Item = SqlGraphEntity<'a>>, extension_name: String, versioned_so: bool, ) -> Result<Self>

pub fn to_file(&self, file: impl AsRef<Path> + Debug) -> Result<()>

pub fn write(&self, out: &mut impl Write) -> Result<()>

pub fn to_dot(&self, file: impl AsRef<Path> + Debug) -> Result<()>

pub fn schema_alias_of(&self, item_index: &NodeIndex) -> Option<String>

pub fn schema_prefix_for(&self, target: &NodeIndex) -> String

pub fn find_type_dependency( &self, owner: &NodeIndex, ty: &dyn TypeIdentifiable, ) -> Option<NodeIndex>

pub fn schema_prefix_for_used_type( &self, owner: &NodeIndex, slot: &str, used_ty: &UsedTypeEntity<'_>, ) -> Result<String>

pub fn to_sql(&self) -> Result<String>

pub fn has_sql_declared_entity( &self, identifier: &SqlDeclared, ) -> Option<&SqlDeclaredEntity>

pub fn get_module_pathname(&self) -> String

pub fn find_matching_fn(&self, name: &str) -> Option<&PgExternEntity<'a>>